import pytest
import numpy as np

import mapof.marriages as mapel

registered_marriages_distances_to_test = {
    'l1-mutual_attraction',
}


class TestMarriagesDistances:

    @pytest.mark.parametrize("distance_id", registered_marriages_distances_to_test)
    def test_marriages_distances(self, distance_id):
        num_agents = int(np.random.randint(5, 50) * 2)

        instance_1 = mapel.generate_marriages_instance(culture_id='ic',
                                                       num_agents=num_agents)

        instance_2 = mapel.generate_marriages_instance(culture_id='ic',
                                                       num_agents=num_agents)

        distance, mapping = mapel.compute_distance(instance_1, instance_2,
                                                   distance_id=distance_id)
        assert type(float(distance)) is float



import pytest
import numpy as np

import mapof.marriages as mapel


registered_marriages_features_to_test = {
    'summed_rank_minimal_matching',
    'summed_rank_maximal_matching',
    'minimal_rank_maximizing_matching',
    'avg_num_of_bps_for_rand_matching',
    'num_of_bps_min_weight',
}

class TestFeatures:

    @pytest.mark.parametrize("feature_id", registered_marriages_features_to_test)
    def test_marriages_features(self, feature_id):

        num_agents = int(np.random.randint(5, 50) * 2)

        instance = mapel.generate_marriages_instance(culture_id='ic',
                                                     num_agents=num_agents)

        instance.compute_feature(feature_id)



import numpy as np

import pytest

import mapof.marriages as mapel

registered_marriages_cultures_to_test = {
    'ic',
    'id',
    'symmetric',
    'norm-mallows',
    'urn',
    'group_ic',
    'malasym',
    'asymmetric',
    'euclidean',
    'reverse_euclidean',
    'mallows_euclidean',
    'expectation',
    'attributes',
    'fame'
}


class TestCultures:

    @pytest.mark.parametrize("culture_id", registered_marriages_cultures_to_test)
    def test_marriages_cultures(self, culture_id):
        num_agents = int(np.random.randint(5, 50) * 2)

        instance = mapel.generate_marriages_instance(culture_id=culture_id,
                                                     num_agents=num_agents)

        assert instance.num_agents == num_agents
